MicrosoftClarityFlutter class

Constructors

MicrosoftClarityFlutter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCurrentSessionId() Future<String?>
getCurrentSessionUrl() Future<String?>
init({required ClarityConfig config}) Future<bool>
isPaused() Future<bool>
maskView() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() Future<bool>
resume() Future<bool>
sendCustomEvent(String eventName) Future<bool>
setCurrentScreenName(String screenName) Future<bool>
setCustomSessionId(String sessionId) Future<bool>
setCustomTag(String customTagKey, String customTagValue) Future<bool>
setCustomUserId(String userId) Future<bool>
toString() String
A string representation of this object.
inherited
unmaskView() Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited